@@ -9,6 +9,6 @@ use Log::Handler::Plugin::DBI::CreateTable;
 
 # -----------------------------------------
 
-my($config) = config_tiny(undef, 't/config.logger.conf');
+my($config) = config_tiny(undef, File::Spec -> catfile('t', '/config.logger.conf') );
 
 Log::Handler::Plugin::DBI::CreateTable -> new(config => $$config{logger}) -> create_log_table;
